@@ -64,7 +64,7 @@ AddProjectForm::AddProjectForm(int rows, int cols,  Srv* srv, const char* projna
     }
     catch(const char* err)
     {
-	kLogPrintf("ERROR EXCAPTION %s\n",err);
+	kLogPrintf("ERROR EXCEPTION %s\n",err);
     }
     //пересчитываем высоту формы, чтобы влезли все поля и центрируем
     int r,c =0;
@@ -85,7 +85,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 	f = addfield(new_field(1, getwidth()-2, line++, 0, 0, 0));
 	if (!f)
 		ERROREX();
-	if (E_OK != set_field_buffer(f, 0, "Errr"))
+	if (E_OK != set_field_buffer(f, 0, "Error"))
 		ERROREX();
 	if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_RED) | A_BOLD))
 		ERROREX();
@@ -104,7 +104,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 		f = addfield(new_field(1, getwidth()-4, line++, 1, 0, 0));
 		if (E_OK != set_field_buffer(f, 0, s.c_str()))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -118,7 +118,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 			ERROREX();
 		if (E_OK != set_field_buffer(f, 0, s.c_str()))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -132,7 +132,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 			ERROREX();
 		if (E_OK != set_field_buffer(f, 0, s.c_str()))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -146,7 +146,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 			ERROREX();
 		if (E_OK != set_field_buffer(f, 0, s.c_str()))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -164,7 +164,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 			ERROREX();
 		if (E_OK != set_field_buffer(f, 0, s.c_str()))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -192,7 +192,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 			ERROREX();
 		if (E_OK != set_field_buffer(f, 0, s.c_str()))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -208,7 +208,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 			ERROREX();
 		if (E_OK != set_field_buffer(f, 0, "ProjectURL"))
 			ERROREX();
-		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+		if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 			ERROREX();
 		if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 			ERROREX();
@@ -228,7 +228,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 	ERROREX();
     if (E_OK != set_field_buffer(f, 0, "email"))
 	ERROREX();
-    if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+    if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 	ERROREX();
     if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 	ERROREX();
@@ -247,7 +247,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 	ERROREX();
     if (E_OK != set_field_buffer(f, 0, "password"))
 	ERROREX();
-    if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+    if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 	ERROREX();
     if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 	ERROREX();
@@ -268,7 +268,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 	    ERROREX();
 	if (E_OK != set_field_buffer(f, 0, "username"))
 	    ERROREX();
-	if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+	if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 	    ERROREX();
 	if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 	    ERROREX();
@@ -287,7 +287,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 	    ERROREX();
 	if (E_OK != set_field_buffer(f, 0, "teamname"))
 	    ERROREX();
-	if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+	if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 	    ERROREX();
 	if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 	    ERROREX();
@@ -307,7 +307,7 @@ void AddProjectForm::genfields(int& line, Item* project) //создаст мас
 	ERROREX();
     if (E_OK != set_field_buffer(f, 0, "Enter-Ok    Esc-Cancel"))
 	ERROREX();
-    if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD))
+    if (E_OK != set_field_back(f, getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD))
 	ERROREX();
     if (E_OK != field_opts_off(f, O_ACTIVE)) //статический текст
 	ERROREX();
