@@ -20,9 +20,9 @@
 
 #include "resultdom.h"
 
-Item* xmlparse(const char* xml, int len); //xml строка с xml len ее размер в байтах
+Item* xmlparse(const char* xml, int len, std::string& errmsg); //xml строка с xml len ее размер в байтах
 
 char* stripinvalidtag(char* xml, int len);	//ГРЯЗНЫЙ ХАК нужен чтобы до парсинга удалить кривые теги
 						//в сообщениях вида <a href=.. </a> иначе будет ошибка парсинга
 
-#endif // RESULTPARSE_H
\ No newline at end of file
+#endif // RESULTPARSE_H
