@@ -502,7 +502,7 @@ ProjectsSubMenu::ProjectsSubMenu(NRect rect, Srv* srv) : NMenu(rect)
 	if (client_state != NULL)
 	{
 	    std::vector<Item*> projects = client_state->getItems("project");
-        for (uint i = 0; i < projects.size(); i++)
+        for (unsigned int i = 0; i < projects.size(); i++)
 	    {
 		Item* project_name = projects[i]->findItem("project_name");
 		if (project_name != NULL)
@@ -817,7 +817,7 @@ ProjectAllListSubMenu::ProjectAllListSubMenu(NRect rect, Srv* srv) : NMenu(rect)
 	    if (projects != NULL)
 	    {
 		std::vector<Item*> projlist = projects->getItems("project");
-        for (uint i = 0; i < projlist.size(); i++)
+        for (unsigned int i = 0; i < projlist.size(); i++)
 		{
 		    Item* name = projlist[i]->findItem("name");
 		    Item* general_area = projlist[i]->findItem("general_area");
@@ -899,7 +899,7 @@ ProjectAccMgrSubMenu::ProjectAccMgrSubMenu(NRect rect, Srv* srv) : NMenu(rect)
 	    if (projects != NULL)
 	    {
 		std::vector<Item*> mgrlist = projects->getItems("account_manager");
-        for (uint i = 0; i < mgrlist.size(); i++)
+        for (unsigned int i = 0; i < mgrlist.size(); i++)
 		{
 		    Item* name = mgrlist[i]->findItem("name");
 		    if (name != NULL)
